@@ -2,38 +2,32 @@
 
 from __future__ import print_function, absolute_import, division, unicode_literals
 
-# install_requires of ruamel.base is not really required but the old
-# ruamel.base installed __init__.py, and thus a new version should
-# be installed at some point
-
-from typing import Dict, Any  # NOQA
+if False:  # MYPY
+    from typing import Dict, Any  # NOQA
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 14, 5),
-    __version__='0.14.5',
+    version_info=(0, 15, 22),
+    __version__='0.15.22',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
     entry_points=None,
-    install_requires=dict(
-        any=[],
-        py33=['typing'],
-        py34=['typing'],
-        py27=['ruamel.ordereddict', 'typing'],
-        pypy=['typing'],
-    ),
+    since=2014,
+    extras_require={
+        ':platform_python_implementation=="CPython" and python_version<="2.7"':
+        ['ruamel.ordereddict'],
+        'jinja2': ['ruamel.yaml.jinja2>=0.2'],
+        'docs': ['ryd'],
+    },
     ext_modules=[dict(
-            name='_ruamel_yaml',
+        name='_ruamel_yaml',
             src=['ext/_ruamel_yaml.c', 'ext/api.c', 'ext/writer.c', 'ext/dumper.c',
-                'ext/loader.c',
-                'ext/reader.c',
-                'ext/scanner.c',
-                'ext/parser.c',
-                'ext/emitter.c',
+                 'ext/loader.c', 'ext/reader.c', 'ext/scanner.c', 'ext/parser.c',
+                 'ext/emitter.c',
             ],
             lib=[],
-            test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n',  # NOQA
+            # test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n',  # NOQA
         )],
     classifiers=[
         'Programming Language :: Python :: 2.7',
@@ -47,12 +41,20 @@ _package_data = dict(
         'Topic :: Software Development :: Libraries :: Python Modules',
         'Topic :: Text Processing :: Markup',
     ],
+    keywords='yaml 1.2 parser round-trip preserve quotes order config',
     windows_wheels=True,
     read_the_docs='yaml',
     many_linux='libyaml-devel',
     supported=[(2, 7), (3, 3)],  # minimum
+    tox=dict(
+        env='*p',
+        deps='ruamel.std.pathlib',
+        fl8excl='_test/lib',
+    ),
+    rtfd=47359,
 )  # type: Dict[Any, Any]
 
+
 version_info = _package_data['version_info']
 __version__ = _package_data['__version__']
 
